@@ -33,9 +33,10 @@
 #  define KLDAP_DEPRECATED_NO_EXPORT KLDAP_NO_EXPORT KLDAP_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KLDAP_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KLDAP_NO_DEPRECATED
+#    define KLDAP_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
